Class: Google::Apis::AdmobV1beta::BatchCreateAdUnitMappingsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AdmobV1beta::BatchCreateAdUnitMappingsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb
Overview
Request to create a batch of ad unit mappings under the specific AdMob account.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchCreateAdUnitMappingsRequest
constructor
A new instance of BatchCreateAdUnitMappingsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchCreateAdUnitMappingsRequest
Returns a new instance of BatchCreateAdUnitMappingsRequest.
421 422 423 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#requests ⇒ Array<Google::Apis::AdmobV1beta::CreateAdUnitMappingRequest>
Required. The request message specifying the ad unit mappings to create. A
maximum of 100 ad unit mappings can be created in a batch. If the number of ad
unit mappings in the batch request exceed 100, the entire request will be
rejected and no ad unit mappings will be created.
Corresponds to the JSON property requests
419 420 421 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 419 def requests @requests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
426 427 428 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 426 def update!(**args) @requests = args[:requests] if args.key?(:requests) end |