Class: Google::Apis::AdmobV1beta::GenerateMediationReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb

Overview

The streaming response for the AdMob Mediation report where the first response contains the report header, then a stream of row responses, and finally a footer as the last response message. For example: ["header": "date_range": "start_date":"year": 2018, "month": 9, "day": 1, "end_date":"year": 2018, "month": 9, "day": 1, "localization_settings": "currency_code": " USD", "language_code": "en-US" , "row": "dimension_values": "DATE": "value": "20180918", "APP": "value": "ca-app-pub-8123415297019784~ 1001342552", "display_label": "My app name!" , "metric_values": " ESTIMATED_EARNINGS":"decimal_value": "1324746" , "footer":" matching_row_count": 1]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateMediationReportResponse

Returns a new instance of GenerateMediationReportResponse.



706
707
708
# File 'lib/google/apis/admob_v1beta/classes.rb', line 706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Groups data available after report generation, for example, warnings and row counts. Always sent as the last message in the stream response. Corresponds to the JSON property footer



693
694
695
# File 'lib/google/apis/admob_v1beta/classes.rb', line 693

def footer
  @footer
end

#headerGoogle::Apis::AdmobV1beta::ReportHeader

Groups data helps to treat the generated report. Always sent as a first message in the stream response. Corresponds to the JSON property header



699
700
701
# File 'lib/google/apis/admob_v1beta/classes.rb', line 699

def header
  @header
end

#rowGoogle::Apis::AdmobV1beta::ReportRow

A row of the returning report. Corresponds to the JSON property row



704
705
706
# File 'lib/google/apis/admob_v1beta/classes.rb', line 704

def row
  @row
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



711
712
713
714
715
# File 'lib/google/apis/admob_v1beta/classes.rb', line 711

def update!(**args)
  @footer = args[:footer] if args.key?(:footer)
  @header = args[:header] if args.key?(:header)
  @row = args[:row] if args.key?(:row)
end