Class: Google::Apis::AdmobV1beta::GenerateNetworkReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb

Overview

The streaming response for the AdMob Network report where the first response contains the report header, then a stream of row responses, and finally a footer as the last response message. For example: ["header": "dateRange": "startDate":"year": 2018, "month": 9, "day": 1, "endDate":"year": 2018, " month": 9, "day": 1, "localizationSettings": "currencyCode": "USD", " languageCode": "en-US" , "row": "dimensionValues": "DATE":"value": "20180918", "APP": "value": "ca-app-pub-8123415297019784~1001342552", displayLabel: "My app name!" , "metricValues": "ESTIMATED_EARNINGS":" microsValue": 6500000 , "footer":"matchingRowCount": 1]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateNetworkReportResponse

Returns a new instance of GenerateNetworkReportResponse.



779
780
781
# File 'lib/google/apis/admob_v1beta/classes.rb', line 779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Groups data available after report generation, for example, warnings and row counts. Always sent as the last message in the stream response. Corresponds to the JSON property footer



766
767
768
# File 'lib/google/apis/admob_v1beta/classes.rb', line 766

def footer
  @footer
end

#headerGoogle::Apis::AdmobV1beta::ReportHeader

Groups data helps to treat the generated report. Always sent as a first message in the stream response. Corresponds to the JSON property header



772
773
774
# File 'lib/google/apis/admob_v1beta/classes.rb', line 772

def header
  @header
end

#rowGoogle::Apis::AdmobV1beta::ReportRow

A row of the returning report. Corresponds to the JSON property row



777
778
779
# File 'lib/google/apis/admob_v1beta/classes.rb', line 777

def row
  @row
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



784
785
786
787
788
# File 'lib/google/apis/admob_v1beta/classes.rb', line 784

def update!(**args)
  @footer = args[:footer] if args.key?(:footer)
  @header = args[:header] if args.key?(:header)
  @row = args[:row] if args.key?(:row)
end