Class: Google::Apis::AdmobV1beta::ListMediationGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb

Overview

Response for the mediation groups list request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMediationGroupsResponse

Returns a new instance of ListMediationGroupsResponse.



936
937
938
# File 'lib/google/apis/admob_v1beta/classes.rb', line 936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mediation_groupsArray<Google::Apis::AdmobV1beta::MediationGroup>

The resulting mediation groups for the requested account. Corresponds to the JSON property mediationGroups



928
929
930
# File 'lib/google/apis/admob_v1beta/classes.rb', line 928

def mediation_groups
  @mediation_groups
end

#next_page_tokenString

If not empty, indicates that there may be more mediation groups for the request; this value should be passed in a new ListMediationGroupsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


934
935
936
# File 'lib/google/apis/admob_v1beta/classes.rb', line 934

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



941
942
943
944
# File 'lib/google/apis/admob_v1beta/classes.rb', line 941

def update!(**args)
  @mediation_groups = args[:mediation_groups] if args.key?(:mediation_groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end