Class: Google::Apis::AdmobV1beta::LocalizationSettings
- Inherits:
-
Object
- Object
- Google::Apis::AdmobV1beta::LocalizationSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb
Overview
Localization settings for reports, such as currency and language. It affects how metrics are calculated.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Currency code of the earning related metrics, which is the 3-letter code defined in ISO 4217.
-
#language_code ⇒ String
Language used for any localized text, such as some dimension value display labels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocalizationSettings
constructor
A new instance of LocalizationSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocalizationSettings
Returns a new instance of LocalizationSettings.
992 993 994 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
Currency code of the earning related metrics, which is the 3-letter code
defined in ISO 4217. The daily average rate is used for the currency
conversion. Defaults to the account currency code if unspecified.
Corresponds to the JSON property currencyCode
983 984 985 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 983 def currency_code @currency_code end |
#language_code ⇒ String
Language used for any localized text, such as some dimension value display
labels. The language tag defined in the IETF BCP47. Defaults to 'en-US' if
unspecified.
Corresponds to the JSON property languageCode
990 991 992 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 990 def language_code @language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
997 998 999 1000 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 997 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @language_code = args[:language_code] if args.key?(:language_code) end |