Class: Google::Apis::AdmobV1beta::MediationAbExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb

Overview

The mediation A/B experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MediationAbExperiment

Returns a new instance of MediationAbExperiment.



1074
1075
1076
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#control_mediation_linesArray<Google::Apis::AdmobV1beta::MediationAbExperimentExperimentMediationLine>

Output only. The experiment mediation lines for control. They are inherited from the parent mediation group. It is an output only field. Corresponds to the JSON property controlMediationLines



1011
1012
1013
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1011

def control_mediation_lines
  @control_mediation_lines
end

#display_nameString

The display name for the mediation A/B experiment. Corresponds to the JSON property displayName

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1016

def display_name
  @display_name
end

#end_timeString

Output only. The time at which the experiment was ended or target to end (in UTC). Corresponds to the JSON property endTime

Returns:

  • (String)


1022
1023
1024
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1022

def end_time
  @end_time
end

#experiment_idString

Output only. Unique identifier for the mediation A/B experiment. It is an output only property. Corresponds to the JSON property experimentId

Returns:

  • (String)


1028
1029
1030
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1028

def experiment_id
  @experiment_id
end

#mediation_group_idString

Output only. The mediation group id this experiment belongs to. This can be used for filtering the experiments in the list experiments API. Corresponds to the JSON property mediationGroupId

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1034

def mediation_group_id
  @mediation_group_id
end

#nameString

Resource name for this experiment. The format is accounts/publisher_id/ mediationGroups/mediation_group_id/mediationAbExperiment/ mediation_group_experiment_id. For example: accounts/pub-9876543210987654/ mediationGroups/0123456789/ mediationAbExperiment/12345 Corresponds to the JSON property name

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1042

def name
  @name
end

#start_timeString

Output only. The time at which the experiment was started (in UTC). Corresponds to the JSON property startTime

Returns:

  • (String)


1047
1048
1049
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1047

def start_time
  @start_time
end

#stateString

Output only. The state of the experiment. It is an output only field. Corresponds to the JSON property state

Returns:

  • (String)


1052
1053
1054
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1052

def state
  @state
end

#treatment_mediation_linesArray<Google::Apis::AdmobV1beta::MediationAbExperimentExperimentMediationLine>

The experiment mediation lines created for the treatment. They will be used for serving when the experiment status is RUNNING. Corresponds to the JSON property treatmentMediationLines



1058
1059
1060
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1058

def treatment_mediation_lines
  @treatment_mediation_lines
end

#treatment_traffic_percentageFixnum

The percentage of the mediation A/B experiment traffic that will be send to the treatment (variant B). The remainder is sent to the control (variant A). The percentage is expressed as an integer in the inclusive range of [1,99]. See https://support.google.com/admob/answer/9572326 for details. Corresponds to the JSON property treatmentTrafficPercentage

Returns:

  • (Fixnum)


1066
1067
1068
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1066

def treatment_traffic_percentage
  @treatment_traffic_percentage
end

#variant_leaderString

Output only. The variant leader for the experiment according to some key metrics. Corresponds to the JSON property variantLeader

Returns:

  • (String)


1072
1073
1074
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1072

def variant_leader
  @variant_leader
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1079

def update!(**args)
  @control_mediation_lines = args[:control_mediation_lines] if args.key?(:control_mediation_lines)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @experiment_id = args[:experiment_id] if args.key?(:experiment_id)
  @mediation_group_id = args[:mediation_group_id] if args.key?(:mediation_group_id)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @treatment_mediation_lines = args[:treatment_mediation_lines] if args.key?(:treatment_mediation_lines)
  @treatment_traffic_percentage = args[:treatment_traffic_percentage] if args.key?(:treatment_traffic_percentage)
  @variant_leader = args[:variant_leader] if args.key?(:variant_leader)
end