Class: Google::Apis::AdmobV1beta::MediationGroupMediationGroupLine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb

Overview

Settings for an ad network used by a mediation group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MediationGroupMediationGroupLine

Returns a new instance of MediationGroupMediationGroupLine.



1236
1237
1238
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_source_idString

The ID of the ad source this mediation line is associated with. Corresponds to the JSON property adSourceId

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1185

def ad_source_id
  @ad_source_id
end

#ad_unit_mappingsHash<String,String>

References of the ad unit mappings for each ad unit associated with this mediation line. Key is the ad unit ID, value is resource name of the ad unit mapping. For mediation lines where the ad source id is the AdMob Network, ad unit mappings will be ignored. Corresponds to the JSON property adUnitMappings

Returns:

  • (Hash<String,String>)


1193
1194
1195
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1193

def ad_unit_mappings
  @ad_unit_mappings
end

#cpm_microsFixnum

The CPM for this allocation line. $0.01 is the minimum allowed amount. For LIVE CPM modes, the default amount is $0.01. This value is ignored if cpm_mode is LIVE. Warning: "USD" is the only supported currency at the moment. The unit is in micros. Corresponds to the JSON property cpmMicros

Returns:

  • (Fixnum)


1201
1202
1203
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1201

def cpm_micros
  @cpm_micros
end

#cpm_modeString

Indicates how the CPM for this mediation line is provided. Note that MANUAL and LIVE are the only fully-supported mode at the moment. Please use the AdMob UI (https://admob.google.com) if you wish to create or update to other cpm modes. Corresponds to the JSON property cpmMode

Returns:

  • (String)


1209
1210
1211
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1209

def cpm_mode
  @cpm_mode
end

#display_nameString

User-provided label for this mediation line. The maximum length allowed is 255 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1215
1216
1217
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1215

def display_name
  @display_name
end

#experiment_variantString

Output only. The Mediation A/B experiment variant to which the mediation group line belongs to. Corresponds to the JSON property experimentVariant

Returns:

  • (String)


1221
1222
1223
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1221

def experiment_variant
  @experiment_variant
end

#idString

The 16 digit ID for this mediation line e.g. 0123456789012345. When creating a new mediation group line, use a distinct negative integer as the ID place holder. Corresponds to the JSON property id

Returns:

  • (String)


1228
1229
1230
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1228

def id
  @id
end

#stateString

The status of the mediation group line. Only enabled mediation group lines will be served. Corresponds to the JSON property state

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1234

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1241

def update!(**args)
  @ad_source_id = args[:ad_source_id] if args.key?(:ad_source_id)
  @ad_unit_mappings = args[:ad_unit_mappings] if args.key?(:ad_unit_mappings)
  @cpm_micros = args[:cpm_micros] if args.key?(:cpm_micros)
  @cpm_mode = args[:cpm_mode] if args.key?(:cpm_mode)
  @display_name = args[:display_name] if args.key?(:display_name)
  @experiment_variant = args[:experiment_variant] if args.key?(:experiment_variant)
  @id = args[:id] if args.key?(:id)
  @state = args[:state] if args.key?(:state)
end