Class: Google::Apis::AdmobV1beta::MediationGroupTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb

Overview

Set of criteria targeted by this mediation group. For example, a mediation group can target specific ad unit IDs, platform, format and geo location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MediationGroupTargeting

Returns a new instance of MediationGroupTargeting.



1295
1296
1297
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_unit_idsArray<String>

Ad units targeted by this mediation group. Example: "ca-app-pub-1234/8790". Corresponds to the JSON property adUnitIds

Returns:

  • (Array<String>)


1261
1262
1263
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1261

def ad_unit_ids
  @ad_unit_ids
end

#excluded_region_codesArray<String>

The Unicode country/region code (CLDR) of a location, such as "US". Unset if this mediation group does not exclude any region. Corresponds to the JSON property excludedRegionCodes

Returns:

  • (Array<String>)


1267
1268
1269
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1267

def excluded_region_codes
  @excluded_region_codes
end

#formatString

Ad format targeted by this mediation group. Examples: "BANNER", "NATIVE". Corresponds to the JSON property format

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1272

def format
  @format
end

#idfa_targetingString

The parameter can be used to target ad requests based on the availability of the IDFA. If set to ALL, the mediation group applies to all ad requests (with or without IDFA). If set to AVAILABLE, the mediation group applies to ad requests with IDFA. If set to NOT_AVAILABLE, the mediation group applies to ad requests without IDFA. Doesn't need to be specified for an ANDROID device. Corresponds to the JSON property idfaTargeting

Returns:

  • (String)


1281
1282
1283
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1281

def idfa_targeting
  @idfa_targeting
end

#platformString

Describes the platform of the app. Examples: "IOS", "ANDROID". Corresponds to the JSON property platform

Returns:

  • (String)


1286
1287
1288
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1286

def platform
  @platform
end

#targeted_region_codesArray<String>

The Unicode country/region code (CLDR) of a location, such as "US". Unset if this mediation group targets all available regions. For more information, see http://www.unicode.org/reports/tr35/#unicode_region_subtag. Corresponds to the JSON property targetedRegionCodes

Returns:

  • (Array<String>)


1293
1294
1295
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1293

def targeted_region_codes
  @targeted_region_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1300

def update!(**args)
  @ad_unit_ids = args[:ad_unit_ids] if args.key?(:ad_unit_ids)
  @excluded_region_codes = args[:excluded_region_codes] if args.key?(:excluded_region_codes)
  @format = args[:format] if args.key?(:format)
  @idfa_targeting = args[:idfa_targeting] if args.key?(:idfa_targeting)
  @platform = args[:platform] if args.key?(:platform)
  @targeted_region_codes = args[:targeted_region_codes] if args.key?(:targeted_region_codes)
end