Class: Google::Apis::AdmobV1beta::MediationGroup
- Inherits:
-
Object
- Object
- Google::Apis::AdmobV1beta::MediationGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb
Overview
Describes an AdMob Mediation group.
Instance Attribute Summary collapse
-
#display_name ⇒ String
User provided name for the mediation group.
-
#mediation_ab_experiment_state ⇒ String
Output only.
-
#mediation_group_id ⇒ String
The ID of the mediation group.
-
#mediation_group_lines ⇒ Hash<String,Google::Apis::AdmobV1beta::MediationGroupMediationGroupLine>
The mediation lines used for serving for this mediation group.
-
#name ⇒ String
Resource name for this mediation group.
-
#state ⇒ String
The status of the mediation group.
-
#targeting ⇒ Google::Apis::AdmobV1beta::MediationGroupTargeting
Set of criteria targeted by this mediation group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MediationGroup
constructor
A new instance of MediationGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MediationGroup
Returns a new instance of MediationGroup.
1162 1163 1164 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
User provided name for the mediation group. The maximum length allowed is 120
characters.
Corresponds to the JSON property displayName
1122 1123 1124 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1122 def display_name @display_name end |
#mediation_ab_experiment_state ⇒ String
Output only. The state of the mediation a/b experiment that belongs to this
mediation group.
Corresponds to the JSON property mediationAbExperimentState
1128 1129 1130 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1128 def mediation_ab_experiment_state @mediation_ab_experiment_state end |
#mediation_group_id ⇒ String
The ID of the mediation group. Example: "0123456789". This is a read only
property.
Corresponds to the JSON property mediationGroupId
1134 1135 1136 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1134 def mediation_group_id @mediation_group_id end |
#mediation_group_lines ⇒ Hash<String,Google::Apis::AdmobV1beta::MediationGroupMediationGroupLine>
The mediation lines used for serving for this mediation group. Key is the ID
of the mediation group line. For creation, use distinct negative values as
placeholder.
Corresponds to the JSON property mediationGroupLines
1141 1142 1143 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1141 def mediation_group_lines @mediation_group_lines end |
#name ⇒ String
Resource name for this mediation group. Format is: accounts/publisher_id/
mediationGroups/mediation_group_id Example: accounts/pub-9876543210987654/
mediationGroups/0123456789
Corresponds to the JSON property name
1148 1149 1150 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1148 def name @name end |
#state ⇒ String
The status of the mediation group. Only enabled mediation groups will be
served.
Corresponds to the JSON property state
1154 1155 1156 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1154 def state @state end |
#targeting ⇒ Google::Apis::AdmobV1beta::MediationGroupTargeting
Set of criteria targeted by this mediation group. For example, a mediation
group can target specific ad unit IDs, platform, format and geo location.
Corresponds to the JSON property targeting
1160 1161 1162 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1160 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1167 1168 1169 1170 1171 1172 1173 1174 1175 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1167 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @mediation_ab_experiment_state = args[:mediation_ab_experiment_state] if args.key?(:mediation_ab_experiment_state) @mediation_group_id = args[:mediation_group_id] if args.key?(:mediation_group_id) @mediation_group_lines = args[:mediation_group_lines] if args.key?(:mediation_group_lines) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @targeting = args[:targeting] if args.key?(:targeting) end |