Class: Google::Apis::AdmobV1beta::ReportFooter
- Inherits:
-
Object
- Object
- Google::Apis::AdmobV1beta::ReportFooter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admob_v1beta/classes.rb,
lib/google/apis/admob_v1beta/representations.rb,
lib/google/apis/admob_v1beta/representations.rb
Overview
Groups data available after report generation, for example, warnings and row counts. Always sent as the last message in the stream response.
Instance Attribute Summary collapse
-
#matching_row_count ⇒ Fixnum
Total number of rows that matched the request.
-
#warnings ⇒ Array<Google::Apis::AdmobV1beta::ReportWarning>
Warnings associated with generation of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportFooter
constructor
A new instance of ReportFooter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportFooter
Returns a new instance of ReportFooter.
1649 1650 1651 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#matching_row_count ⇒ Fixnum
Total number of rows that matched the request. Warning: This count does NOT
always match the number of rows in the response. Do not make that assumption
when processing the response.
Corresponds to the JSON property matchingRowCount
1642 1643 1644 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1642 def matching_row_count @matching_row_count end |
#warnings ⇒ Array<Google::Apis::AdmobV1beta::ReportWarning>
Warnings associated with generation of the report.
Corresponds to the JSON property warnings
1647 1648 1649 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1647 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1654 1655 1656 1657 |
# File 'lib/google/apis/admob_v1beta/classes.rb', line 1654 def update!(**args) @matching_row_count = args[:matching_row_count] if args.key?(:matching_row_count) @warnings = args[:warnings] if args.key?(:warnings) end |